@@ -2,20 +2,20 @@
 function(x, data=sys.parent(), method="bf") {
   if (method != "bf")
     stop("Only 'bf', Brown-Forsyth method is currently available.")
-  if.R(r={
+  ## if.R(r={
     do.formula.trellis <- NA ## make R-2.6.0dev happy
     lPF <- latticeParseFormula(x, data=data)
     y <- lPF$left
     group <- lPF$right
     y.name <- lPF$left.name
     group.name <- lPF$right.name
-  }, s={
-    dft <- do.formula.trellis(x)
-    y          <-    eval(dft$expr[[1]], local=data)
-    group      <-    eval(dft$expr[[2]], local=data)
-    y.name     <- deparse(dft$expr[[1]])
-    group.name <- deparse(dft$expr[[2]])
-  })
+  ## }, s={
+  ##   dft <- do.formula.trellis(x)
+  ##   y          <-    eval(dft$expr[[1]], local=data)
+  ##   group      <-    eval(dft$expr[[2]], local=data)
+  ##   y.name     <- deparse(dft$expr[[1]])
+  ##   group.name <- deparse(dft$expr[[2]])
+  ## })
   hov.bf(y, group, y.name, group.name)
 }
 
